Documentation
¶
Overview ¶
Package contact provides requests and response structures to achieve Contact API actions.
Index ¶
- type CreateContactRequest
- type CreateContactResponse
- type DeleteContactRequest
- type DeleteContactResponse
- type DisableContactRequest
- type DisableContactResponse
- type EnableContactRequest
- type EnableContactResponse
- type GetContactRequest
- type GetContactResponse
- type UpdateContactRequest
- type UpdateContactResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateContactRequest ¶
type CreateContactRequest struct {
APIKey string `json:"apiKey,omitempty"`
Method string `json:"method,omitempty"`
To string `json:"to,omitempty"`
Username string `json:"username,omitempty"`
}
CreateContactRequest provides necessary parameter structure for creating contact
type CreateContactResponse ¶
type CreateContactResponse struct {
Id string `json:"id"`
Status string `json:"status"`
Code int `json:"code"`
}
Create contact response structure
type DeleteContactRequest ¶
type DeleteContactRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Username string `url:"username,omitempty"`
}
DeleteContactRequest provides necessary parameter structure for deleting a contact
type DeleteContactResponse ¶
Delete contact response structure
type DisableContactRequest ¶
type DisableContactRequest struct {
APIKey string `json:"apiKey,omitempty"`
Id string `json:"id,omitempty"`
Username string `json:"username,omitempty"`
}
DisableContactRequest provides necessary parameter structure for disabling contact
type DisableContactResponse ¶
type DisableContactResponse struct {
Status string `json:"status"`
}
Disable contact response structure
type EnableContactRequest ¶
type EnableContactRequest struct {
APIKey string `json:"apiKey,omitempty"`
Id string `json:"id,omitempty"`
Username string `json:"username,omitempty"`
}
EnableContactRequest provides necessary parameter structure for enabling a contact
type EnableContactResponse ¶
type EnableContactResponse struct {
Status string `json:"status"`
}
Enable contact response structure
type GetContactRequest ¶
type GetContactRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Username string `url:"username,omitempty"`
}
GetContactRequest provides necessary parameter structure for requesting contact information
type GetContactResponse ¶
type GetContactResponse struct {
Id string `json:"id,omitempty"`
Method string `json:"method,omitempty"`
To string `json:"to,omitempty"`
DisabledReason string `json:"disabledReason, omitempty"`
Enabled bool `json:"enabled, omitempty"`
}
Get contact response structure
type UpdateContactRequest ¶
type UpdateContactRequest struct {
APIKey string `json:"apiKey,omitempty"`
Id string `json:"id,omitempty"`
To string `json:"to,omitempty"`
Username string `json:"username,omitempty"`
}
UpdateContactRequest provides necessary parameter structure for updating a contact
type UpdateContactResponse ¶
type UpdateContactResponse struct {
Id string `json:"id"`
Status string `json:"status"`
Code int `json:"code"`
}
Update contact response structure