Documentation
¶
Overview ¶
Package escalation provides requests and response structures to achieve Escalation API actions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateEscalationRequest ¶
type CreateEscalationRequest struct {
APIKey string `json:"apiKey,omitempty"`
Name string `json:"name,omitempty"`
Rules []Rule `json:"rules,omitempty"`
}
CreateEscalationRequest provides necessary parameter structure for creating escalation
type CreateEscalationResponse ¶
type CreateEscalationResponse struct {
Id string `json:"id"`
Status string `json:"status"`
Code int `json:"code"`
}
Create escalation response structure
type DeleteEscalationRequest ¶
type DeleteEscalationRequest struct {
APIKey string `url:"apiKey,omitempty"`
ID string `url:"id,omitempty"`
Name string `url:"name,omitempty"`
}
DeleteEscalationRequest provides necessary parameter structure for deleting an escalation
type DeleteEscalationResponse ¶
Delete escalation response structure
type GetEscalationRequest ¶
type GetEscalationRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Name string `url:"name,omitempty"`
}
GetEscalationRequest provides necessary parameter structure for requesting escalation information
type GetEscalationResponse ¶
type GetEscalationResponse struct {
Id string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
Team string `json:"team,omitempty"`
Rules []Rule `json:"rules,omitempty"`
}
Get escalation structure
type ListEscalationsRequest ¶
type ListEscalationsRequest struct {
APIKey string `url:"apiKey,omitempty"`
}
ListEscalationRequest provides necessary parameter structure for listing escalations
type ListEscalationsResponse ¶
type ListEscalationsResponse struct {
Escalations []GetEscalationResponse `json:"escalations,omitempty"`
}
List escalations response structure
type Rule ¶
type Rule struct {
Delay int `json:"delay"`
Notify string `json:"notify,omitempty"`
NotifyType string `json:"notifyType,omitempty"`
NotifyCondition string `json:"notifyCondition,omitempty"`
}
Rule defines the structure for each escalation rule definition
type UpdateEscalationRequest ¶
type UpdateEscalationRequest struct {
APIKey string `json:"apiKey,omitempty"`
Id string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
Rules []Rule `json:"rules,omitempty"`
}
UpdateEscalationRequest provides necessary parameter structure for updating an escalation
type UpdateEscalationResponse ¶
Update escalation response structure